PerAppProxyMode enum

Represents the per-app proxy mode

Inheritance
Available extensions

Values

off → const PerAppProxyMode
include → const PerAppProxyMode
exclude → const PerAppProxyMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String? value) PerAppProxyMode

Constants

values → const List<PerAppProxyMode>
A constant List of the values in this enum, in order of their declaration.